@@ -11,7 +11,6 @@ test_that("coordinates works", {
 test_that("print and show", {
   expect_output(show(tr))
   expect_output(print(tr))
-  expect_silent(summary(tr))
-  
-  expect_silent({plot(tr[seq(1, 1000, by = 5), ]); lines(tr); text(tr, lab = tr$Deployment)})
+  expect_s3_class(summary(tr), "summary.TORdata")
+
 })
